import { PID, Reference } from '../erlang-types';
import { Process, Monitor, Task } from './process';
import { Mailbox } from './mailbox';
import { Scheduler } from './scheduler';
export interface IProcessSystem {
    spawn(fun: Task): PID;
    spawn(module: Object, fun: string, args: any[]): PID;
    spawn_link(fun: Task): PID;
    spawn_link(module: Object, fun: string, args: any[]): PID;
    spawn_monitor(fun: Task): [PID, Reference];
    spawn_monitor(module: Object, fun: string, args: any[]): [PID, Reference];
    link(pid: PID): void;
    unlink(pid: PID): void;
    register(name: string, pid: PID): void;
    whereis(name: string): PID | undefined;
    unregister(pid: any): void;
    registered(): Array<string>;
    pid(): PID;
    pidof(pid: PID | Process | string): PID | undefined;
    send<T>(pid: PID, msg: T): T;
    receive(fun: Task, timeout?: number, timeoutFn?: Function): any;
    sleep(duration: number): any;
    exit(reason: any): any;
    exit(pid: PID, reason: any): any;
    error(reason: any): any;
    process_flag(flag: string, value: string): any;
    process_flag(pid: PID | Process | string, flag: string, value: string): any;
    put(key: string, value: any): void;
    get(key: any, default_value?: any): any;
    get_process_dict(): any;
    get_keys(): any;
    get_keys(value: any): any;
    erase(): any;
    erase(key: any): any;
    is_alive(pid: PID): any;
    make_ref(): any;
    list(): PID[];
    monitor(pid: PID): any;
    demonitor(ref: Reference): any;
    self(): PID;
}
/**
 * Process System
 */
export declare class ProcessSystem implements IProcessSystem {
    static DEFAULT_THROTTLE: number;
    pids: Map<PID, Process>;
    mailboxes: Map<PID, Mailbox>;
    names: Map<string, PID>;
    links: Map<PID, Set<any>>;
    monitors: Map<Reference, Monitor>;
    suspended: Map<PID, Function>;
    current_process: Process | undefined;
    main_process_pid: PID | undefined;
    scheduler: Scheduler;
    constructor();
    static run(fun: any, args: any, context?: any): IterableIterator<any>;
    spawn(...args: any[]): PID;
    spawn_link(...args: any[]): PID;
    link(pid: PID): void;
    unlink(pid: PID): void;
    spawn_monitor(...args: any[]): [PID, Reference];
    schedule(task: Function, pid?: PID): void;
    set_current(id: any): void;
    add_proc(fun: Task, args: any[], linked: boolean, monitored?: boolean): Process;
    remove_proc(pid: any, exitreason: any): void;
    monitor(pid: PID): Reference;
    demonitor(ref: any): boolean;
    exit(one: PID | any, two?: any): void;
    pid(): PID;
    pidof(id: PID | Process | string): PID | undefined;
    whereis(name: string): PID | undefined;
    send(id: PID | Process | string, msg: any): void;
    receive(fun: Function, timeout?: number, timeoutFn?: () => boolean): (number | symbol | Function | null)[];
    sleep(duration: any): any[];
    suspend(fun: Function): void;
    delay(fun: Function, time: number): void;
    trap_exits(): void;
    make_ref(): Reference;
    register(name: string, pid: PID): void;
    unregister(pid: PID): void;
    registered(): string[];
    process_flag(...args: any[]): any;
    put(key: any, value: any): void;
    get_process_dict(): Object | undefined;
    get(key: any, default_value?: any): any;
    get_keys(value?: any): string[];
    erase(key?: any): void;
    is_alive(pid: any): boolean;
    list(): PID[];
    self(): PID;
    error(reason: any): void;
}
